package com.redxun.knowledge.analysis.controller;

import com.redxun.common.annotation.ClassDefine;
import com.redxun.common.base.entity.JsonResult;
import com.redxun.knowledge.analysis.entity.vo.SearchParticipleWordCloudVo;
import com.redxun.knowledge.analysis.entity.vo.SearchVisitHistogramVo;
import com.redxun.knowledge.analysis.service.AnalysisCommonServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * 文件名: CommonController
 * 作者: zizg
 * 时间: 2023/3/17
 * 描述:
 * 修改人:
 * 修改时间:
 * 修改内容:
 */
@Slf4j
@RestController
@RequestMapping("/api-knowledge/analysis")
@Api(tags = "业务--系统页面访问量统计")
@ClassDefine(title = "业务--系统页面访问量统计", alias = "CommonController", path = "/api-knowledge/analysis", packages = "analysis", packageName = "子系统名称")
public class AnalysisCommonController {

    @Autowired
    private AnalysisCommonServiceImpl analysisCommonService;

    @ApiOperation("PC 各模块整体数量统计")
    @GetMapping("totalAmount")
    public JsonResult totalAmount() {
        Map<String, Object> result = analysisCommonService.totalAmount();
        return JsonResult.getSuccessResult(result);
    }

    @ApiOperation("PC 获取搜索服务访问量分布柱状图数据")
    @GetMapping("searchVisitHistogram")
    public JsonResult searchVisitHistogram(){
        SearchVisitHistogramVo searchVisitHistogramVo = analysisCommonService.searchVisitHistogram();
        return JsonResult.getSuccessResult(searchVisitHistogramVo);
    }

    @ApiOperation("PC 获取搜索服务分词的词云数据")
    @GetMapping("searchParticipleWordCloud")
    public JsonResult searchParticipleWordCloud(@RequestParam(value = "tops", required = false, defaultValue = "100") Integer tops) {
        List<SearchParticipleWordCloudVo> result = analysisCommonService.searchParticipleWordCloud(tops);
        return JsonResult.getSuccessResult(result);
    }

    @ApiOperation("PC 查询各类型（维基、文档）知识数量")
    @GetMapping("knowledgeTypeAmount")
    public JsonResult knowledgeTypeAmount() {
        Map<String, Object> result = analysisCommonService.knowledgeTypeAmount();
        return JsonResult.getSuccessResult(result);
    }
}
